==> kernDeepStackNet_1.0.0.tar.gz: kernDeepStackNet/man/gDerivMu.Rd <==
\name{gDerivMu}
\alias{gDerivMu}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Derivative of the link function evaluated at the expected values
}
\description{
Evaluates the first derivative of the link function, given an exponential family distribution, at the expected values. The expected values are estimated with a generalized linear model assuming a Gaussian distribution.
}
\usage{
gDerivMu(mu)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mu}{
Fitted values of the model (numeric vector)
}
}
%\details{
%
%}
\value{
Numeric scalar with gives the generalized cross-validation score. The kernel deep stacking network used to calculate the score is available as attribute.
}
\references{
Simon N. Wood, (2006), 
\emph{Generalized Additive Models: An Introduction with R},
Taylor \& Francis Group LLC
}
\author{
Thomas Welchowski \email{welchow@imbie.meb.uni-bonn.de}
}

\note{
This function is not intended to be called directly by the user. Should only be used by experienced users, who want to customize the model. It is called in the model selection process of the kernel deep stacking network, e.g. \code{\link{tuneKDSN}}.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{calcTrA}}, \code{\link{calcWdiag}}, \code{\link{varMu}}
}

%\examples{
%
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ models & regression }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line

==> kernDeepStackNet_2.0.1.tar.gz: kernDeepStackNet/man/gDerivMu.Rd <==
\name{gDerivMu}
\alias{gDerivMu}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Derivative of the link function evaluated at the expected values
}
\description{
Evaluates the first derivative of the link function, given an exponential family distribution, at the expected values. The expected values are estimated with a generalized linear model assuming a Gaussian distribution.
}
\usage{
gDerivMu(mu)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{mu}{
Fitted values of the model (numeric vector)
}
}
%\details{
%
%}
\value{
Numeric scalar with gives the generalized cross-validation score. The kernel deep stacking network used to calculate the score is available as attribute.
}
\references{
Simon N. Wood, (2006), 
\emph{Generalized Additive Models: An Introduction with R},
Taylor \& Francis Group LLC
}
\author{
Thomas Welchowski \email{welchow@imbie.meb.uni-bonn.de}
}

\note{
This function is not intended to be called directly by the user. Should only be used by experienced users, who want to customize the model. %%It is called in the model selection process of the kernel deep stacking network, e.g. \code{\link{tuneKDSN}}.
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{calcTrA}}, \code{\link{calcWdiag}}, \code{\link{varMu}}
}

%\examples{
%
%}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ models & regression }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
